==> xl-react-components-0.16.62.tgz: package/app/languages/en-US/react-components.lang.js <==
import React from 'react';
import {validDateExample} from '../../utils/date-utils';

export default {
    addButton: 'Add',
    addNewRowButton: 'Add new row',
    addNewTabLabel: 'Add new tab',
    apiLabel: 'API',
    applyDefaultValueButton: 'Apply default value',
    browseButton: 'Browse',
    clearAllLabel: 'Clear all',
    collapseAll: 'Collapse All',
    createAnotherLabel: 'Create another',
    dateIsNotAllowed: 'Chosen date is not allowed',
    dipLookupToggleTooltipMessage: 'Toggle between input field and predefined value selection.',
    disabledLabel: 'Disabled',
    displayModeLabel: 'Display Mode',
    displaySizeLabel: 'Size',
    displaySizeLargeLabel: 'Large',
    displaySizeMediumLabel: 'Medium',
    displaySizeSmallLabel: 'Small',
    duplicateTag: (tag) => <span>Item <label>{tag}</label> is already added.</span>,
    emptyKeyErrorMessage: 'Empty key is not allowed.',
    encryptedChangedValueLabel: '*(changed) encrypted value*',
    encryptedUnchangedValueLabel: '*(unchanged) encrypted value*',
    fieldIsRequired: 'This field is required',
    filterByPlaceholder: 'Filter by placeholder...',
    focusLabel: 'Focus',
    hideButton: 'Hide',
    invalidDateExampleMessage: `Example: ${validDateExample}`,
    invalidDateFormatMessage: 'Format: <%= dateFormat %>',
    keyAlreadyInUse: (key) => <span>Key <label>{key}</label> is already in use.</span>,
    keyLabel: 'Key',
    keyPlaceholder: 'Add key...',
    modelLabel: 'Model',
    moreLabel: 'more',
    nameLabel: 'Name',
    noKeyValueDefined: 'No key/value defined',
    noSearchResults: 'No search results',
    passwordLabel: 'Password',
    pristineLabel: 'Pristine',
    propertyLabel: 'Property',
    reportPaginationTotals: 'Total: <%= total %>',
    requiredLabel: 'Required',
    resetPristinityButton: 'Reset pristinity',
    searchLabel: 'Search for key/value...',
    selectAllLabel: 'Select all',
    selectedRow: 'Selected row',
    showButton: 'Show',
    showMessagesLabel: 'Show messages',
    spinnerMessage: 'Loading',
    tableEmptyDataMessage: 'No data available for the selected filter',
    tableErrorMessage: 'Error occurred while fetching report',
    tableFilterInputPlaceholderFallback: 'Search',
    tableLoadingMessage: 'Data loading… This process may take some time.',
    toggleLoadingLabel: 'Toggle loading',
    uploadedMessage: 'Uploaded <%= currentProgress %>%',
    validLabel: 'Valid',
    valueIsRequired: 'Value is required',
    valueLabel: 'Value',
    valuePlaceholder: 'Add value...'
};

==> xl-react-components-0.18.103.tgz: package/app/languages/en-US/react-components.lang.js <==
import React from 'react';
import {validDateExample} from '../../utils/date-utils';

export default {
    addButton: 'Add',
    addNewRowButton: 'Add new row',
    addNewTabLabel: 'Add new tab',
    addPatchEntryButton: 'Add patch entry',
    apiLabel: 'API',
    applyDefaultValueButton: 'Apply default value',
    browseButton: 'Browse',
    cancelButton: 'Cancel',
    clearAllLabel: 'Clear all',
    collapseAll: 'Collapse All',
    createAnotherLabel: 'Create another',
    dateIsNotAllowed: 'Chosen date is not allowed',
    dipLookupToggleTooltipMessage: 'Toggle between input field and predefined value selection.',
    disabledLabel: 'Disabled',
    discardButton: 'Discard',
    displayModeLabel: 'Display Mode',
    displaySizeLabel: 'Size',
    displaySizeLargeLabel: 'Large',
    displaySizeMediumLabel: 'Medium',
    displaySizeSmallLabel: 'Small',
    duplicateTag: (tag) => <span>Item <label>{tag}</label> is already added.</span>,
    emptyKeyErrorMessage: 'Empty key is not allowed.',
    encryptedChangedValueLabel: '*(changed) encrypted value*',
    encryptedUnchangedValueLabel: '*(unchanged) encrypted value*',
    fieldIsRequired: 'This field is required',
    filterByPlaceholder: 'Filter by placeholder...',
    focusLabel: 'Focus',
    hideButton: 'Hide',
    invalidCiInTheListMessage: 'One or more configuration item is invalid',
    invalidDateExampleMessage: `Example: ${validDateExample}`,
    invalidDateFormatMessage: 'Format: <%= dateFormat %>',
    invalidItem: 'Invalid item',
    keyAlreadyInUse: (key) =>
        <span className="duplicate-key-error">
            <span className="outer-text">Key </span>
            <strong title={key}>{key}</strong>
            <span className="outer-text"> is already in use.</span>
        </span>,
    keyLabel: 'Key',
    keyPlaceholder: 'Add key...',
    modelLabel: 'Model',
    modifyPatchTooltip: 'Modify patch',
    moreLabel: 'more',
    nameLabel: 'Name',
    noKeyValueDefined: 'No key/value defined',
    noSample: 'No sample',
    noSearchResults: 'No search results',
    passwordLabel: 'Password',
    patchDictionaryLostChangesMessage: 'You have unsaved changes. Do you want to save or discard them?',
    patchDictionaryLostChangesTitle: 'Save changed patch',
    patchDictionaryPatchWithPanelTitle: 'Patch with',
    patchDictionaryPathTitle: 'Patch dictionary sample path',
    patchDictionarySamplePanelTitle: 'Sample',
    patchEditorDescription:
        'Patch dictionaries by selecting path and then action. Available actions are Replace/Edit, Add or Delete',
    pristineLabel: 'Pristine',
    propertyLabel: 'Property',
    removePatchTooltip: 'Remove patch',
    reportPaginationTotals: 'Total: <%= total %>',
    requiredLabel: 'Required',
    resetPristinityButton: 'Reset pristinity',
    searchLabel: 'Search for key/value...',
    selectAllLabel: 'Select all',
    selectedRow: 'Selected row',
    showButton: 'Show',
    showMessagesLabel: 'Show messages',
    spinnerMessage: 'Loading',
    tableEmptyDataMessage: 'No data available for the selected filter',
    tableErrorMessage: 'Error occurred while fetching report',
    tableFilterInputPlaceholderFallback: 'Search',
    tableLoadingMessage: 'Data loading… This process may take some time.',
    toggleLoadingLabel: 'Toggle loading',
    uploadedMessage: 'Uploaded <%= currentProgress %>%',
    validLabel: 'Valid',
    valueIsRequired: 'Value is required',
    valueLabel: 'Value',
    valuePlaceholder: 'Add value...'
};
